#
# spec file for package libolecf
#
# Copyright (c) 2016 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           libolecf
%define lname	libolecf1
%define timestamp	20160107
Version:        0~%timestamp
Release:        1.3
Summary:        Library and tools to access the OLE 2 Compound File (OLECF) format
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Productivity/File utilities
Url:            https://github.com/libyal/libolecf/wiki
Source:         https://github.com/libyal/libolecf/releases/download/%timestamp/%name-alpha-%timestamp.tar.gz
Source2:        OLE_Compound_File_format.pdf
BuildRequires:  pkg-config
BuildRequires:  python-devel
BuildRequires:  pkgconfig(libbfio)
BuildRequires:  pkgconfig(libcdata) >= 20160108
BuildRequires:  pkgconfig(libcfile)
BuildRequires:  pkgconfig(libclocale)
BuildRequires:  pkgconfig(libcnotify)
BuildRequires:  pkgconfig(libcpath)
BuildRequires:  pkgconfig(libcsplit)
BuildRequires:  pkgconfig(libcsystem) >= 20120425
BuildRequires:  pkgconfig(libcthreads) >= 20130723
BuildRequires:  pkgconfig(libfguid) >= 20140103
BuildRequires:  pkgconfig(libfole) >= 20120426
BuildRequires:  pkgconfig(libuna)

# testing fails with external package from factory - verified Jan 27, 2016
#BuildRequires:  pkgconfig(libfdatetime) > 20150507
#BuildRequires:  pkgconfig(libcstring) > 20150101
#BuildRequires:  pkgconfig(libcerror) > 20150407
#BuildRequires:  pkgconfig(libfvalue) > 20151226
# released, but not yet packaged.  This is the only user in OBS.
#BuildRequires:  pkgconfig(libwfps) > 20150104
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Library and tools to access the OLE 2 Compound File (OLECF) format. The OLE 2 Compound File format is used to store certain versions of Microsoft Office files, thumbs.db and other file formats. 

%package -n %lname
Summary:        Library to access the OLE 2 Compound File (OLECF) format
License:        LGPL-3.0+
Group:          System/Libraries

%description -n %lname
Library to access the OLE 2 Compound File (OLECF) format. The OLE 2 Compound File format is used to store certain versions of Microsoft Office files, thumbs.db and other file formats. 


%package tools
Summary:        Tools to access the OLE 2 Compound File (OLECF) format
License:        LGPL-3.0+
Group:          System/Filesystems
Requires:       %lname = %version

%description tools
Tools to access the OLE 2 Compound File (OLECF) format. The OLE 2 Compound File format is used to store certain versions of Microsoft Office files, thumbs.db and other file formats. 

 
%package devel
Summary:        Development files for %name
License:        LGPL-3.0+ and GFDL-1.3+
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libolecf is a library to access the OLE 2 Compound File (OLECF) format.

This subpackage contains libraries and header files for developing
applications that want to make use of %name.

%package -n python-%name
Summary:        Python bindings for libolecf
License:        LGPL-3.0+
Group:          Development/Libraries/Python
Requires:       %lname = %version
Requires:       python
Provides:       pyolecf = %version

%description -n python-%name
Python bindings for libolecf, which can read MS IE cache files.

%prep
%setup -qn libolecf-%timestamp
cp "%SOURCE2" .

%build
%configure --disable-static --enable-wide-character-type --enable-python
make %{?_smp_mflags}

%install
make install DESTDIR="%buildroot"
find %buildroot -name '*.la' -delete

%post   -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog
%_libdir/libolecf.so.*

%files tools
%defattr(-,root,root)
%_bindir/olecf*
%_mandir/man1/olecf*.1*

%files devel
%defattr(-,root,root)
%doc OLE_Compound_File_format.pdf
%_includedir/libolecf.h
%_includedir/libolecf/
%_libdir/libolecf.so
%_libdir/pkgconfig/libolecf.pc
%_mandir/man3/libolecf.3*

%files -n python-%name
%defattr(-,root,root)
%doc AUTHORS COPYING README
%python_sitearch/pyolecf.so

%changelog
* Tue Jan 26 2016 Greg.Freemyer@gmail.com
- update to v0~20160107
  * worked on Python 3 support
  * 2016 update
- use libcdata from factory, not internal.  Tested via plaso/run_tests.py
- use libcerror internal package.  Build fails with factory version
- use libcstring internal package.  Build fails with factory version
- use libfvalue internal package.  Build fails with factory version
* Sat Jan 23 2016 Greg.Freemyer@gmail.com
- update to v0~20151223
  * worked on format support
  * applied updates
  * worked on Python bindings
  * changed version for pypi repacking
  * worked on setup.py
  * bug fixes after fuzzing with AFL
  * improved support file without directory entries
  * added more bounds checks
- required by plaso v1.4
- update BuildRequires libfvalue to require version 0~20151226
* Wed Jan 14 2015 Greg.Freemyer@gmail.com
- update to v0~20150106
  * 2015 update
  * worked on Python 3 support
  * worked on tests
  * code clean up
  * bug fix in Python-bindings
  * update Python-bindings tests
  * worked on libfwps support
- update URL to the new github site
- replace Source: field with fully defined URL
- remove DL-URL comment
- start using new libyal packages from OBS, not internal version
- remove %%if opensuse logic.  Not needed with libyal in security:forensics
* Thu Aug 28 2014 Greg.Freemyer@gmail.com
- use libfdatetime internal package.  With external factory version fails testing.
- use libcdata internal package.  With external factory version fails testing.
* Wed Aug 20 2014 Greg.Freemyer@gmail.com
- add "Requires:  %%lname = %%version" to tools sub-project
- add "Provice:  pyolecf" to match upstream requires
* Wed Aug 13 2014 Greg.Freemyer@gmail.com
- updated to 0~20140801
  * worked on Python bindings
  * bug fix in Python-bindings
  * worked on olecfmount Dokan support
  * updated dependencies
  * small changes to Makefile
  * worked on setup.py
  * 2014 update
- use external package for libfguid
* Sat Nov 23 2013 Greg.Freemyer@gmail.com
- updated to 20131108
  * added support for 0 value sub directory entry not being used as index.
* Wed Oct 16 2013 Greg.Freemyer@gmail.com
- add %%if logic around BuildRequires to allow use of internal packages on older distros
* Wed Oct 16 2013 Greg.Freemyer@gmail.com
- initial package (v0~20131012)
